@@ -1,6 +1,14 @@
 import logging
 import sys
 from deepdriver.sdk import util
+import os
+
+# Google introduced an incompatibility into protobuf-4.21.x
+# that is not backwards compatible with many libraries.
+# Once those libraries have updated to rebuild their _pb2.py files,
+# this can be removed.
+os.environ["PROTOCOL_BUFFERS_PYTHON_IMPLEMENTATION"] = "python"
+
 logger = logging.getLogger("deepdriver")
 
 console_handler = logging.StreamHandler(sys.stdout)
@@ -27,6 +35,7 @@ from deepdriver.sdk.data_types.dataFrame import DataFrame
 from deepdriver.sdk.data_types.image import Image
 from deepdriver.sdk.data_types.table import Table
 
+from deepdriver.intergration.keras import keras
 config = Config()
 
 
