@@ -58,7 +58,7 @@ def get_http_host_ip() -> str:
     return urlsplit('//' + http_host).hostname
 
 
-def update_config(run_id: int, config_item_dict: list):
+def update_config(run_id: int, team_name: str, exp_name: str, config_item_dict: list):
     def makeItem(item):
         key, value = item
         if isinstance(value, int):
@@ -86,6 +86,8 @@ def update_config(run_id: int, config_item_dict: list):
     rsp: UpdateConfigResponse = get_stub().update_config(UpdateConfigRequest(
         runId=run_id,
         item=item,
+        teamName=team_name,
+        expName=exp_name,
         authorization=f"Bearer {http_interface.get_jwt_key()}",
     ))
 
@@ -102,7 +104,7 @@ def send_alert(run_id: int, team_name: str, exp_name: str, alert_msg: str):
 
     return rsp.rsp_result.result == "success"
 
-def upload_log(run_id: int, log_step: int, item_dict: Dict[str, Union[int, str, float, bool]]) -> bool:
+def upload_log(run_id: int, team_name: str, exp_name: str, log_step: int, item_dict: Dict[str, Union[int, str, float, bool]]) -> bool:
     item_list = []
 
     def makeItem(item):
@@ -125,11 +127,12 @@ def upload_log(run_id: int, log_step: int, item_dict: Dict[str, Union[int, str,
     item = map(makeItem, item_dict.items())
 
     # item = [LogItem(key=key, value=str(value)) for key, value in item_dict.items()]
-
     rsp: UploadLogResponse = get_stub().upload_log(UploadLogRequest(
         item=item,
         step=LogStep(num=log_step),
         run=RunInfo(run_id=run_id),
+        teamName=team_name,
+        expName=exp_name,
         authorization=f"Bearer {http_interface.get_jwt_key()}",
     ))
     return rsp.rsp_result.result == "success"
